[sr-dev] git:master: doxygen: a bunch of doxygen fixes in dialog module

Henning Westerholt henning.westerholt at 1und1.de
Wed Sep 21 23:54:48 CEST 2011


Module: sip-router
Branch: master
Commit: 377b2f7569902b4f23d4b0431fcac681214be703
URL:    http://git.sip-router.org/cgi-bin/gitweb.cgi/sip-router/?a=commit;h=377b2f7569902b4f23d4b0431fcac681214be703

Author: Henning Westerholt <hw at kamailio.org>
Committer: Henning Westerholt <hw at kamailio.org>
Date:   Wed Sep 21 23:54:31 2011 +0200

doxygen: a bunch of doxygen fixes in dialog module

---

 modules_k/dialog/dlg_handlers.c |   11 ++++++-----
 modules_k/dialog/dlg_handlers.h |    5 +++--
 modules_k/dialog/dlg_hash.c     |    1 +
 modules_k/dialog/dlg_profile.c  |    4 +---
 modules_k/dialog/dlg_profile.h  |    4 +---
 modules_k/dialog/dlg_timer.c    |    4 +---
 modules_k/dialog/dlg_timer.h    |    4 +---
 7 files changed, 14 insertions(+), 19 deletions(-)

diff --git a/modules_k/dialog/dlg_handlers.c b/modules_k/dialog/dlg_handlers.c
index a5eb007..7bfdbab 100644
--- a/modules_k/dialog/dlg_handlers.c
+++ b/modules_k/dialog/dlg_handlers.c
@@ -285,7 +285,7 @@ error0:
  * \brief Function that executes BYE reply callbacks
  * \param t transaction, unused
  * \param type type of the callback, should be TMCB_RESPONSE_FWDED
- * \param param saved dialog structure inside the callback
+ * \param params saved dialog structure inside the callback
  */
 static void dlg_terminated_confirmed(struct cell* t,
                                      int type,
@@ -665,9 +665,9 @@ void dlg_tmcb_dummy(struct cell* t, int type, struct tmcb_params *param)
 
 /*!
  * \brief Register a transaction on a dialog
- * \param t transaction
- * \param type type of the entered callback
- * \param param saved dialog structure in the callback
+ * \param msg SIP message
+ * \param t registered transaction
+ * \param dlg dialog to which the transaction should registered
  */
 static int store_dlg_in_tm(struct sip_msg* msg,
                             struct cell* t,
@@ -732,8 +732,9 @@ static void store_dlg_in_tm_cb (struct cell* t,
  * from the dlg_manage function in the configuration script.
  * \see dlg_onreq
  * \see w_dlg_manage
- * \param msg SIP message
+ * \param req SIP message
  * \param t transaction
+ * \param run_initial_cbs if set zero, initial callbacks are not executed
  * \return 0 on success, -1 on failure
  */ 
 int dlg_new_dialog(struct sip_msg *req, struct cell *t, const int run_initial_cbs)
diff --git a/modules_k/dialog/dlg_hash.c b/modules_k/dialog/dlg_hash.c
index 35e5bc1..ddfd714 100644
--- a/modules_k/dialog/dlg_hash.c
+++ b/modules_k/dialog/dlg_hash.c
@@ -468,6 +468,7 @@ not_found:
 /*!
  * \brief Helper function to get a dialog corresponding to a SIP message
  * \see get_dlg
+ * \param h_entry hash index in the directory list
  * \param callid callid
  * \param ftag from tag
  * \param ttag to tag
diff --git a/modules_k/dialog/dlg_profile.c b/modules_k/dialog/dlg_profile.c
index aeeec40..2e69291 100644
--- a/modules_k/dialog/dlg_profile.c
+++ b/modules_k/dialog/dlg_profile.c
@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * Copyright (C) 2008 Voice System SRL
  *
  * This file is part of Kamailio, a free SIP server.
@@ -307,7 +305,7 @@ void destroy_linkers(struct dlg_profile_link *linker)
  * \brief Cleanup a profile
  * \param msg SIP message
  * \param flags unused
- * \param unused
+ * \param param unused
  * \return 1
  */
 int profile_cleanup( struct sip_msg *msg, unsigned int flags, void *param )
diff --git a/modules_k/dialog/dlg_profile.h b/modules_k/dialog/dlg_profile.h
index f11af76..1bb04f6 100644
--- a/modules_k/dialog/dlg_profile.h
+++ b/modules_k/dialog/dlg_profile.h
@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * Copyright (C) 2008 Voice System SRL
  *
  * This file is part of Kamailio, a free SIP server.
@@ -118,7 +116,7 @@ struct dlg_profile_table* search_dlg_profile(str *name);
  * \brief Cleanup a profile
  * \param msg SIP message
  * \param flags unused
- * \param unused
+ * \param param unused
  * \return 1
  */
 int profile_cleanup( struct sip_msg *msg, unsigned int flags, void *param );
diff --git a/modules_k/dialog/dlg_timer.c b/modules_k/dialog/dlg_timer.c
index 7308eee..caad461 100644
--- a/modules_k/dialog/dlg_timer.c
+++ b/modules_k/dialog/dlg_timer.c
@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * Copyright (C) 2006 Voice System SRL
  *
  * This file is part of Kamailio, a free SIP server.
@@ -268,7 +266,7 @@ static inline struct dlg_tl* get_expired_dlgs(unsigned int time)
 /*!
  * \brief Timer routine for expiration of dialogs
  * Timer handler for expiration of dialogs, runs the global timer handler on them.
- * \param time for expiration checks
+ * \param ticks time for expiration checks
  * \param attr unused
  */
 void dlg_timer_routine(unsigned int ticks , void * attr)
diff --git a/modules_k/dialog/dlg_timer.h b/modules_k/dialog/dlg_timer.h
index 2ee2080..7223956 100644
--- a/modules_k/dialog/dlg_timer.h
+++ b/modules_k/dialog/dlg_timer.h
@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * Copyright (C) 2006 Voice System SRL
  *
  * This file is part of Kamailio, a free SIP server.
@@ -106,7 +104,7 @@ int update_dlg_timer(struct dlg_tl *tl, int timeout);
 /*!
  * \brief Timer routine for expiration of dialogs
  * Timer handler for expiration of dialogs, runs the global timer handler on them.
- * \param time for expiration checks
+ * \param ticks time for expiration checks
  * \param attr unused
  */
 void dlg_timer_routine(unsigned int ticks , void * attr);




More information about the sr-dev mailing list
diff --git a/modules_k/dialog/dlg_handlers.h b/modules_k/dialog/dlg_handlers.h
index eef5a8f..9bd83a7 100644
--- a/modules_k/dialog/dlg_handlers.h
+++ b/modules_k/dialog/dlg_handlers.h
@@ -124,11 +124,12 @@ void dlg_ontimeout( struct dlg_tl *tl);
  * from the dlg_manage function in the configuration script.
  * \see dlg_onreq
  * \see w_dlg_manage
  * \param msg SIP message
  * \param t transaction
+ * \param run_initial_cbs if set zero, initial callbacks are not executed
  * \return 0 on success, -1 on failure
  */ 
-int dlg_new_dialog(struct sip_msg *msg, struct cell *t, const int run_initial_cbs);
+int dlg_new_dialog(struct sip_msg *req, struct cell *t, const int run_initial_cbs);
 
 
 /*!
@@ -124,11 +124,12 @@ void dlg_ontimeout( struct dlg_tl *tl);
  * \see dlg_onreq
  * \see w_dlg_manage
- * \param msg SIP message
+ * \param req SIP message
  * \param t transaction